@@ -1,8 +1,10 @@
-import pandas as pd
-from itertools import groupby
-from matminer.data_retrieval.retrieve_base import BaseDataRetrieval
-from tqdm import tqdm
 from functools import reduce
+from itertools import groupby
+
+import pandas as pd
+from tqdm import tqdm
+
+from matminer.data_retrieval.retrieve_base import BaseDataRetrieval
 
 __author__ = "Anubhav Jain <ajain@lbl.gov>"
 
@@ -18,7 +20,7 @@ class MongoDataRetrieval(BaseDataRetrieval):
         self.coll = coll
 
     def api_link(self):
-        return "data from\n{}".format(self.coll)
+        return f"data from\n{self.coll}"
 
     def get_dataframe(
         self,
@@ -65,7 +67,7 @@ class MongoDataRetrieval(BaseDataRetrieval):
                     vals = [int(v) if is_int(v) else v for v in vals]
                     data = reduce(lambda e, k: e[k], vals, d)
                     row_data.append(data)
-                except:
+                except Exception:
                     if not strict:
                         row_data.append(float("nan"))
                     else:
@@ -116,7 +118,7 @@ def is_int(x):
     try:
         int(x)
         return True
-    except:
+    except Exception:
         return False
 
 
