@@ -1,13 +1,13 @@
-import unittest
 import os
+import unittest
 
-import requests
 import numpy as np
-from pandas.api.types import is_numeric_dtype, is_object_dtype, is_bool_dtype
-from pymatgen.core.structure import Structure, Composition
+import requests
+from pandas.api.types import is_bool_dtype, is_numeric_dtype, is_object_dtype
+from pymatgen.core.structure import Composition, Structure
 
-from matminer.datasets.tests.base import DatasetTest, do_complete_test
 from matminer.datasets.dataset_retrieval import load_dataset
+from matminer.datasets.tests.base import DatasetTest, do_complete_test
 
 
 class DataSetsTest(DatasetTest):
@@ -45,7 +45,7 @@ class DataSetsTest(DatasetTest):
             # Test all columns are there
             self.assertEqual(
                 sorted(list(df)),
-                sorted([header for header in self.dataset_dict[dataset_name]["columns"].keys()]),
+                sorted(header for header in self.dataset_dict[dataset_name]["columns"].keys()),
             )
 
             # Test each column for appropriate type
@@ -638,6 +638,12 @@ class MatminerDatasetsTest(DataSetsTest):
 
         self.universal_dataset_check("ricci_boltztrap_mp_tabular", object_headers, numeric_headers)
 
+    def test_superconductivity2018(self):
+        object_headers = ["composition"]
+        numeric_headers = ["Tc"]
+
+        self.universal_dataset_check("superconductivity2018", object_headers, numeric_headers)
+
 
 class MatbenchDatasetsTest(DataSetsTest):
     """
