@@ -1,37 +1,24 @@
 """
 Site featurizers that fingerprint a site using local geometry.
 """
-import os
 import copy
+import os
 
-import ruamel.yaml as yaml
 import numpy as np
-from pymatgen.core import Structure
-from pymatgen.analysis.local_env import (
-    LocalStructOrderParams,
-    VoronoiNN,
-    CrystalNN,
-)
 import pymatgen.analysis.local_env
+import ruamel.yaml as yaml
+from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import (
+    MultiWeightsChemenvStrategy,
+    SimplestChemenvStrategy,
+)
+from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_finder import (
+    LocalGeometryFinder,
+)
+from pymatgen.analysis.local_env import CrystalNN, LocalStructOrderParams, VoronoiNN
 
 from matminer.featurizers.base import BaseFeaturizer
 from matminer.featurizers.utils.stats import PropertyStats
 from matminer.utils.caching import get_nearest_neighbors
-from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_finder import (
-    LocalGeometryFinder,
-)
-from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import (
-    SimplestChemenvStrategy,
-    MultiWeightsChemenvStrategy,
-)
-
-with open(
-    os.path.join(os.path.dirname(pymatgen.analysis.local_env.__file__), "cn_opt_params.yaml"),
-    "r",
-) as f:
-    cn_motif_op_params = yaml.safe_load(f)
-with open(os.path.join(os.path.dirname(__file__), "cn_target_motif_op.yaml"), "r") as f:
-    cn_target_motif_op = yaml.safe_load(f)
 
 
 class AGNIFingerprints(BaseFeaturizer):
@@ -45,12 +32,12 @@ class AGNIFingerprints(BaseFeaturizer):
     direction-resolved fingerprints.
     Atomic fingerprints describe the local environment of an atom and are
     computed using the function:
-    :math:`A_i(\eta) = \sum\limits_{i \\ne j} e^{-(\\frac{r_{ij}}{\eta})^2} f(r_{ij})`
-    where :math:`i` is the index of the atom, :math:`j` is the index of a neighboring atom, :math:`\eta` is a scaling function,
+    :math:`A_i(\\eta) = \\sum\\limits_{i \\ne j} e^{-(\\frac{r_{ij}}{\\eta})^2} f(r_{ij})`
+    where :math:`i` is the index of the atom, :math:`j` is the index of a neighboring atom, :math:`\\eta` is a scaling function,
     :math:`r_{ij}` is the distance between atoms :math:`i` and :math:`j`, and :math:`f(r)` is a cutoff function where
-    :math:`f(r) = 0.5[\cos(\\frac{\pi r_{ij}}{R_c}) + 1]` if :math:`r < R_c` and :math:`0` otherwise.
+    :math:`f(r) = 0.5[\\cos(\\frac{\\pi r_{ij}}{R_c}) + 1]` if :math:`r < R_c` and :math:`0` otherwise.
     The direction-resolved fingerprints are computed using
-    :math:`V_i^k(\eta) = \sum\limits_{i \\ne j} \\frac{r_{ij}^k}{r_{ij}} e^{-(\\frac{r_{ij}}{\eta})^2} f(r_{ij})`
+    :math:`V_i^k(\\eta) = \\sum\\limits_{i \\ne j} \\frac{r_{ij}^k}{r_{ij}} e^{-(\\frac{r_{ij}}{\\eta})^2} f(r_{ij})`
     where :math:`r_{ij}^k` is the :math:`k^{th}` component of :math:`\\bold{r}_i - \\bold{r}_j`.
     Parameters:
     TODO: Differentiate between different atom types (maybe as another class)
@@ -115,7 +102,7 @@ class AGNIFingerprints(BaseFeaturizer):
                 if d is None:
                     labels.append("AGNI eta=%.2e" % e)
                 else:
-                    labels.append("AGNI dir=%s eta=%.2e" % (d, e))
+                    labels.append(f"AGNI dir={d} eta={e:.2e}")
         return labels
 
     def citations(self):
@@ -179,6 +166,10 @@ class OPSiteFingerprint(BaseFeaturizer):
         dist_exp=2,
         zero_ops=True,
     ):
+
+        cn_target_motif_op = load_cn_target_motif_op()
+        cn_motif_op_params = load_cn_motif_op_params()
+
         self.cn_target_motif_op = (
             copy.deepcopy(cn_target_motif_op) if target_motifs is None else copy.deepcopy(target_motifs)
         )
@@ -222,7 +213,7 @@ class OPSiteFingerprint(BaseFeaturizer):
             neighbors = struct.get_neighbors(s, r)
 
         # Smoothen distance, but use relative distances.
-        dmin = min([n[1] for n in neighbors])
+        dmin = min(n[1] for n in neighbors)
         neigh_dist = [[n[0], n[1] / dmin] for n in neighbors]
 
         neigh_dist_alldrs = {}
@@ -352,7 +343,7 @@ class OPSiteFingerprint(BaseFeaturizer):
         labels = []
         for cn, li in self.cn_target_motif_op.items():
             for e in li:
-                labels.append("{} CN_{}".format(e, cn))
+                labels.append(f"{e} CN_{cn}")
         return labels
 
     def citations(self):
@@ -389,10 +380,11 @@ class CrystalNNFingerprint(BaseFeaturizer):
             **kwargs: other settings to be passed into CrystalNN class
         """
         if preset == "cn":
-            op_types = dict([(k + 1, ["wt"]) for k in range(24)])
+            op_types = {k + 1: ["wt"] for k in range(24)}
             return CrystalNNFingerprint(op_types, **kwargs)
 
         elif preset == "ops":
+            cn_target_motif_op = load_cn_target_motif_op()
             op_types = copy.deepcopy(cn_target_motif_op)
             for k in range(24):
                 if k + 1 in op_types:
@@ -425,6 +417,7 @@ class CrystalNNFingerprint(BaseFeaturizer):
             self.chem_props = list(chem_info.keys())
         else:
             self.chem_info = None
+        cn_motif_op_params = load_cn_motif_op_params()
 
         self.ops = {}  # load order parameter objects & paramaters
         for cn, t_list in self.op_types.items():
@@ -523,10 +516,10 @@ class CrystalNNFingerprint(BaseFeaturizer):
             cn = k + 1
             if cn in list(self.ops.keys()):
                 for op in self.op_types[cn]:
-                    labels.append("{} CN_{}".format(op, cn))
+                    labels.append(f"{op} CN_{cn}")
         if self.chem_info is not None:
             for prop in self.chem_props:
-                labels.append("{} local diff".format(prop))
+                labels.append(f"{prop} local diff")
         return labels
 
     def citations(self):
@@ -867,3 +860,27 @@ class ChemEnvSiteFingerprint(BaseFeaturizer):
 
     def implementors(self):
         return ["Nils E. R. Zimmermann"]
+
+
+def load_cn_motif_op_params():
+    """
+    Load the file for the local env motif parameters into a dictionary.
+
+    Returns:
+        (dict)
+    """
+    with open(
+        os.path.join(os.path.dirname(pymatgen.analysis.local_env.__file__), "cn_opt_params.yaml"),
+    ) as f:
+        return yaml.safe_load(f)
+
+
+def load_cn_target_motif_op():
+    """
+    Load the file fpor the
+
+    Returns:
+        (dict)
+    """
+    with open(os.path.join(os.path.dirname(__file__), "cn_target_motif_op.yaml")) as f:
+        return yaml.safe_load(f)
