@@ -4,22 +4,21 @@ import unittest
 
 from monty.json import MontyEncoder
 from pandas import DataFrame, MultiIndex
-
+from pymatgen.core import SETTINGS, Composition, Element, Lattice, Structure
 from pymatgen.core.structure import IStructure
-from pymatgen.core import Composition, Lattice, Structure, Element, SETTINGS
 from pymatgen.util.testing import PymatgenTest
 
 from matminer.featurizers.conversions import (
+    ASEAtomstoStructure,
+    CompositionToOxidComposition,
+    CompositionToStructureFromMP,
+    DictToObject,
+    JsonToObject,
+    PymatgenFunctionApplicator,
     StrToComposition,
     StructureToComposition,
     StructureToIStructure,
-    DictToObject,
-    JsonToObject,
     StructureToOxidStructure,
-    CompositionToOxidComposition,
-    CompositionToStructureFromMP,
-    PymatgenFunctionApplicator,
-    ASEAtomstoStructure,
 )
 
 try:
@@ -341,6 +340,13 @@ class TestConversions(PymatgenTest):
         df = pfa2.featurize_dataframe(df, "structure")
         self.assertArrayEqual(df["anonymous formula"].tolist(), ["A0.5B1.5", "AB"])
 
+        # Test for compatibility with return_errors
+        df = DataFrame(data={"structure": [si, cscl, float("nan")]})
+
+        df = pfa2.featurize_dataframe(df, "structure", return_errors=True, ignore_errors=True)
+        self.assertEqual(df["anonymous formula"].tolist()[:2], ["A0.5B1.5", "AB"])
+        self.assertTrue(math.isnan(df["anonymous formula"].iloc[-1]))
+
     @unittest.skipIf(not ase_loaded, "ASE must be installed for test_ase_conversion to run!")
     def test_ase_conversion(self):
         a2s = ASEAtomstoStructure()
