@@ -1,14 +1,15 @@
 import unittest
-import pandas as pd
 
+import numpy as np
+import pandas as pd
+from sklearn.exceptions import NotFittedError
+from sympy.parsing.sympy_parser import parse_expr
+
+from matminer.featurizers.base import MultipleFeaturizer
 from matminer.featurizers.function import (
     FunctionFeaturizer,
     generate_expressions_combinations,
 )
-from matminer.featurizers.base import MultipleFeaturizer
-import numpy as np
-from sympy.parsing.sympy_parser import parse_expr
-from sklearn.exceptions import NotFittedError
 
 
 class TestFunctionFeaturizer(unittest.TestCase):
@@ -71,7 +72,7 @@ class TestFunctionFeaturizer(unittest.TestCase):
         # Test latexification
         ff = FunctionFeaturizer(latexify_labels=True)
         new_df = ff.fit_featurize_dataframe(self.test_df, "a", inplace=False)
-        self.assertTrue("\sqrt{a}" in new_df.columns)
+        self.assertTrue(r"\sqrt{a}" in new_df.columns)
         # Ensure error is thrown with no labels
         ff = FunctionFeaturizer(latexify_labels=False)
         self.assertRaises(NotFittedError, ff.feature_labels)
