@@ -1,4 +1,4 @@
-from sklearn.base import TransformerMixin, BaseEstimator
+from sklearn.base import BaseEstimator, TransformerMixin
 
 
 class ItemSelector(BaseEstimator, TransformerMixin):
